@@ -32,24 +32,64 @@ class CXGate(TwoQubitGate):
                 target_qubit,
                 to_anf(sp.Xor(pathsum.f[control_qubit], pathsum.f[target_qubit])),
             )
-            return PathSum(pathsum.P, new_f, pathsum.pathvar)
+            return PathSum(pathsum.P, new_f, pathsum.pathvar, pathsum._stats)
         else:
             x_i = se.symbols(
-                f"{pathsum.bits[target_qubit]}"
-                if isinstance(target_qubit, int)
-                else str(target_qubit)
-            )
-            x_j = se.symbols(
                 f"{pathsum.bits[control_qubit]}"
                 if isinstance(control_qubit, int)
                 else str(control_qubit)
             )
+            x_j = se.symbols(
+                f"{pathsum.bits[target_qubit]}"
+                if isinstance(target_qubit, int)
+                else str(target_qubit)
+            )
             new_var = sp.Xor(x_i, x_j)
             update_var = logical_to_algebraic(new_var)
-            new_P = pathsum.P.subs(x_i, update_var)
+            new_P = pathsum.P.subs(x_j, update_var)
             new_P = reduce_expression(new_P)
-            new_f = pathsum.f.sub(x_i, new_var)
-            return PathSum(new_P, new_f, pathsum.pathvar)
+            new_f = pathsum.f.sub(x_j, new_var)
+            return PathSum(new_P, new_f, pathsum.pathvar, pathsum._stats)
+
+
+class CYGate(TwoQubitGate):
+    gate_name = "cy"
+
+    def apply(
+        self,
+        pathsum: "PathSum",
+        control_qubit: int | str | se.Symbol,
+        target_qubit: int | str | se.Symbol,
+        is_bra: bool = False,
+    ) -> "PathSum":
+        if not is_bra:
+            x_i = logical_to_algebraic(pathsum.f[control_qubit], 1)
+            x_j = logical_to_algebraic(pathsum.f[target_qubit], 1)
+            new_P = pathsum.P + (se.Rational(3, 4) + se.Rational(1, 2) * x_j) * x_i
+            new_f = pathsum.f.update(
+                target_qubit,
+                to_anf(sp.Xor(pathsum.f[control_qubit], pathsum.f[target_qubit])),
+            )
+        else:
+            x_i = se.symbols(
+                f"{pathsum.bits[control_qubit]}"
+                if isinstance(control_qubit, int)
+                else str(control_qubit)
+            )
+            x_j = se.symbols(
+                f"{pathsum.bits[target_qubit]}"
+                if isinstance(target_qubit, int)
+                else str(target_qubit)
+            )
+            new_var = sp.Xor(x_i, x_j)
+            update_var = logical_to_algebraic(new_var)
+            new_P = (
+                pathsum.P.subs(x_j, update_var)
+                + (se.Rational(3, 4) + se.Rational(1, 2) * x_j) * x_i
+            )
+            new_f = pathsum.f.sub(x_j, new_var)
+        new_P = reduce_expression(new_P)
+        return PathSum(new_P, new_f, pathsum.pathvar, pathsum._stats)
 
 
 class CZGate(TwoQubitGate):
@@ -62,7 +102,6 @@ class CZGate(TwoQubitGate):
         target_qubit: int | str | se.Symbol,
         is_bra: bool = False,
     ) -> "PathSum":
-        # ... (Implementation is the same)
         if not is_bra:
             x_i = logical_to_algebraic(pathsum.f[control_qubit], 1)
             x_j = logical_to_algebraic(pathsum.f[target_qubit], 1)
@@ -80,7 +119,7 @@ class CZGate(TwoQubitGate):
             )
             new_P = pathsum.P + se.Rational(1, 2) * x_i * x_j
         new_P = reduce_expression(new_P)
-        return PathSum(new_P, pathsum.f, pathsum.pathvar)
+        return PathSum(new_P, pathsum.f, pathsum.pathvar, pathsum._stats)
 
 
 class SwapGate(TwoQubitGate):
@@ -93,7 +132,6 @@ class SwapGate(TwoQubitGate):
         qubit2: int | str | se.Symbol,
         is_bra: bool = False,
     ) -> "PathSum":
-        # ... (Implementation is the same)
         if not is_bra:
             f1 = pathsum.f[qubit1]
             f2 = pathsum.f[qubit2]
@@ -113,7 +151,7 @@ class SwapGate(TwoQubitGate):
             new_f = pathsum.f.sub(x_i, temp_sym)
             new_f = new_f.sub(x_j, x_i)
             new_f = new_f.sub(temp_sym, x_j)
-        return PathSum(new_P, new_f, pathsum.pathvar)
+        return PathSum(new_P, new_f, pathsum.pathvar, pathsum._stats)
 
 
 class CHGate(TwoQubitGate):
@@ -177,7 +215,7 @@ class CRkGate(TwoQubitGate):
             )
         new_P = pathsum.P + phase_factor * x_i * x_j
         new_P = reduce_expression(new_P)
-        return PathSum(new_P, pathsum.f, pathsum.pathvar)
+        return PathSum(new_P, pathsum.f, pathsum.pathvar, pathsum._stats)
 
 
 class CRkdgGate(TwoQubitGate):
@@ -213,7 +251,7 @@ class CRkdgGate(TwoQubitGate):
             )
         new_P = pathsum.P + phase_factor * x_i * x_j
         new_P = reduce_expression(new_P)
-        return PathSum(new_P, pathsum.f, pathsum.pathvar)
+        return PathSum(new_P, pathsum.f, pathsum.pathvar, pathsum._stats)
 
 
 class CPGate(TwoQubitGate):
@@ -255,7 +293,7 @@ class CPGate(TwoQubitGate):
             )
         new_P = pathsum.P + phase_factor * x_i * x_j
         new_P = reduce_expression(new_P)
-        return PathSum(new_P, pathsum.f, pathsum.pathvar)
+        return PathSum(new_P, pathsum.f, pathsum.pathvar, pathsum._stats)
 
 
 class CRZGate(TwoQubitGate):
@@ -299,7 +337,7 @@ class CRZGate(TwoQubitGate):
                 self.theta - 2 * self.theta * x_j
             )
         new_P = reduce_expression(new_P)
-        return PathSum(new_P, pathsum.f, pathsum.pathvar)
+        return PathSum(new_P, pathsum.f, pathsum.pathvar, pathsum._stats)
 
 
 class CRYGate(TwoQubitGate):
